@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.10
 # -*- coding: utf-8 -*-
 # ******************************************************************************
 #  $Id$
@@ -42,8 +42,8 @@ XML_FIRST_CHILD_IDX = 2
 
 
 def Usage():
-    print('Usage: build_jp2_from_xml in.xml out.jp2')
-    return 1
+    print("Usage: build_jp2_from_xml in.xml out.jp2")
+    return 2
 
 
 def find_xml_node(ar, element_name, immediate_child=False, only_attributes=False):
@@ -69,8 +69,10 @@ def get_attribute_val(ar, attr_name):
     node = find_xml_node(ar, attr_name, True)
     if node is None or node[XML_TYPE_IDX] != gdal.CXT_Attribute:
         return None
-    if len(ar) > XML_FIRST_CHILD_IDX and \
-            node[XML_FIRST_CHILD_IDX][XML_TYPE_IDX] == gdal.CXT_Text:
+    if (
+        len(ar) > XML_FIRST_CHILD_IDX
+        and node[XML_FIRST_CHILD_IDX][XML_TYPE_IDX] == gdal.CXT_Text
+    ):
         return node[XML_FIRST_CHILD_IDX][XML_VALUE_IDX]
     return None
 
@@ -87,57 +89,61 @@ def get_node_content(node):
 
 def hex_letter_to_number(ch):
     val = 0
-    if ch >= '0' and ch <= '9':
-        val = (ord(ch) - ord('0'))
-    elif ch >= 'a' and ch <= 'f':
-        val = (ord(ch) - ord('a')) + 10
-    elif ch >= 'A' and ch <= 'F':
-        val = (ord(ch) - ord('A')) + 10
+    if ch >= "0" and ch <= "9":
+        val = ord(ch) - ord("0")
+    elif ch >= "a" and ch <= "f":
+        val = (ord(ch) - ord("a")) + 10
+    elif ch >= "A" and ch <= "F":
+        val = (ord(ch) - ord("A")) + 10
     return val
 
 
 def write_hexstring_as_binary(hex_binary_content, out_f):
     for i in range(int(len(hex_binary_content) / 2)):
-        val = hex_letter_to_number(hex_binary_content[2 * i]) * 16 + \
-            hex_letter_to_number(hex_binary_content[2 * i + 1])
-        out_f.write(chr(val).encode('latin1'))
+        val = hex_letter_to_number(
+            hex_binary_content[2 * i]
+        ) * 16 + hex_letter_to_number(hex_binary_content[2 * i + 1])
+        out_f.write(chr(val).encode("latin1"))
 
 
 def parse_field(xml_tree, out_f, src_jp2file):
     # pylint: disable=unused-argument
-    if not (xml_tree[XML_TYPE_IDX] == gdal.CXT_Element and xml_tree[XML_VALUE_IDX] == 'Field'):
-        print('Not a Field element')
+    if not (
+        xml_tree[XML_TYPE_IDX] == gdal.CXT_Element
+        and xml_tree[XML_VALUE_IDX] == "Field"
+    ):
+        print("Not a Field element")
         return False
-    field_name = get_attribute_val(xml_tree, 'name')
+    field_name = get_attribute_val(xml_tree, "name")
     if field_name is None:
-        print('Cannot find Field.name attribute')
+        print("Cannot find Field.name attribute")
         # return False
-    field_type = get_attribute_val(xml_tree, 'type')
+    field_type = get_attribute_val(xml_tree, "type")
     if field_type is None:
-        print('Cannot find Field.type attribute')
+        print("Cannot find Field.type attribute")
         return False
     val = get_node_content(xml_tree)
     if val is None:
-        print('Cannot find Field content')
+        print("Cannot find Field content")
         return False
-    if field_type == 'uint8':
-        out_f.write(struct.pack('>B' * 1, int(val)))
-    elif field_type == 'uint16':
-        out_f.write(struct.pack('>H' * 1, int(val)))
-    elif field_type == 'uint32':
-        out_f.write(struct.pack('>I' * 1, int(val)))
-    elif field_type == 'string':
-        field_size = get_attribute_val(xml_tree, 'size')
+    if field_type == "uint8":
+        out_f.write(struct.pack(">B" * 1, int(val)))
+    elif field_type == "uint16":
+        out_f.write(struct.pack(">H" * 1, int(val)))
+    elif field_type == "uint32":
+        out_f.write(struct.pack(">I" * 1, int(val)))
+    elif field_type == "string":
+        field_size = get_attribute_val(xml_tree, "size")
         if field_size is not None:
             assert len(val) == int(field_size)
-        out_f.write(val.encode('latin1'))
-    elif field_type == 'hexint':
-        field_size = get_attribute_val(xml_tree, 'size')
+        out_f.write(val.encode("latin1"))
+    elif field_type == "hexint":
+        field_size = get_attribute_val(xml_tree, "size")
         if field_size is not None:
             assert len(val) == 2 + 2 * int(field_size)
         write_hexstring_as_binary(val[2:], out_f)
     else:
-        print('Unhandled type %s' % field_type)
+        print("Unhandled type %s" % field_type)
         return False
     return True
 
@@ -164,21 +170,24 @@ marker_map = {
 
 
 def parse_jpc_marker(xml_tree, out_f, src_jp2file):
-    if not (xml_tree[XML_TYPE_IDX] == gdal.CXT_Element and xml_tree[XML_VALUE_IDX] == 'Marker'):
-        print('Not a Marker element')
+    if not (
+        xml_tree[XML_TYPE_IDX] == gdal.CXT_Element
+        and xml_tree[XML_VALUE_IDX] == "Marker"
+    ):
+        print("Not a Marker element")
         return False
-    marker_name = get_attribute_val(xml_tree, 'name')
+    marker_name = get_attribute_val(xml_tree, "name")
     if marker_name is None:
-        print('Cannot find Marker.name attribute')
+        print("Cannot find Marker.name attribute")
         return False
-    if find_xml_node(xml_tree, 'Field', immediate_child=True):
+    if find_xml_node(xml_tree, "Field", immediate_child=True):
         if marker_name not in marker_map:
-            print('Cannot find marker signature for %s' % marker_name)
+            print("Cannot find marker signature for %s" % marker_name)
             return False
         marker_signature = marker_map[marker_name]
-        out_f.write(struct.pack('>H' * 1, marker_signature))
+        out_f.write(struct.pack(">H" * 1, marker_signature))
         pos = out_f.tell()
-        out_f.write(struct.pack('>H' * 1, 0))
+        out_f.write(struct.pack(">H" * 1, 0))
 
         for child_idx in range(XML_FIRST_CHILD_IDX, len(xml_tree)):
             child = xml_tree[child_idx]
@@ -189,23 +198,23 @@ def parse_jpc_marker(xml_tree, out_f, src_jp2file):
 
         new_pos = out_f.tell()
         out_f.seek(pos, 0)
-        out_f.write(struct.pack('>H' * 1, new_pos - pos))
+        out_f.write(struct.pack(">H" * 1, new_pos - pos))
         out_f.seek(new_pos, 0)
     else:
-        offset = get_attribute_val(xml_tree, 'offset')
+        offset = get_attribute_val(xml_tree, "offset")
         if offset is None:
-            if marker_name == 'SOC' or marker_name == 'EOC':
+            if marker_name == "SOC" or marker_name == "EOC":
                 marker_signature = marker_map[marker_name]
-                out_f.write(struct.pack('>H' * 1, marker_signature))
+                out_f.write(struct.pack(">H" * 1, marker_signature))
                 return True
 
-            print('Cannot find Marker.offset attribute')
+            print("Cannot find Marker.offset attribute")
             return False
         offset = int(offset)
 
-        length = get_attribute_val(xml_tree, 'length')
+        length = get_attribute_val(xml_tree, "length")
         if length is None:
-            print('Cannot find Marker.length attribute')
+            print("Cannot find Marker.length attribute")
             return False
         length = int(length)
 
@@ -220,14 +229,14 @@ def parse_jpc_marker(xml_tree, out_f, src_jp2file):
 def parse_jp2codestream(inpath, xml_tree, out_f, src_jp2file=None):
 
     if src_jp2file is None:
-        src_jp2filename = get_attribute_val(xml_tree, 'filename')
+        src_jp2filename = get_attribute_val(xml_tree, "filename")
         if src_jp2filename is None:
-            print('Cannot find JP2KCodeStream.filename attribute')
+            print("Cannot find JP2KCodeStream.filename attribute")
             return False
         if os.path.exists(src_jp2filename):
-            src_jp2file = open(src_jp2filename, 'rb')
+            src_jp2file = open(src_jp2filename, "rb")
         else:
-            src_jp2file = open(os.path.join(inpath, src_jp2filename), 'rb')
+            src_jp2file = open(os.path.join(inpath, src_jp2filename), "rb")
 
     for child_idx in range(XML_FIRST_CHILD_IDX, len(xml_tree)):
         child = xml_tree[child_idx]
@@ -239,153 +248,182 @@ def parse_jp2codestream(inpath, xml_tree, out_f, src_jp2file=None):
 
 
 def parse_jp2_box(xml_tree, out_f, src_jp2file):
-    if not (xml_tree[XML_TYPE_IDX] == gdal.CXT_Element and xml_tree[XML_VALUE_IDX] == 'JP2Box'):
-        print('Not a JP2Box element')
+    if not (
+        xml_tree[XML_TYPE_IDX] == gdal.CXT_Element
+        and xml_tree[XML_VALUE_IDX] == "JP2Box"
+    ):
+        print("Not a JP2Box element")
         return False
-    jp2box_name = get_attribute_val(xml_tree, 'name')
+    jp2box_name = get_attribute_val(xml_tree, "name")
     if jp2box_name is None:
-        print('Cannot find JP2Box.name attribute')
+        print("Cannot find JP2Box.name attribute")
         return False
     if len(jp2box_name) != 4:
-        print('Invalid JP2Box.name : %s' % jp2box_name)
+        print("Invalid JP2Box.name : %s" % jp2box_name)
         return False
-    hex_binary_content = get_node_content(find_xml_node(xml_tree, 'BinaryContent', immediate_child=True))
-    decoded_content = find_xml_node(xml_tree, 'DecodedContent', immediate_child=True)
-    decoded_geotiff = find_xml_node(xml_tree, 'DecodedGeoTIFF', immediate_child=True)
-    text_content = get_node_content(find_xml_node(xml_tree, 'TextContent', immediate_child=True))
-    xml_content = find_xml_node(xml_tree, 'XMLContent', immediate_child=True)
-    jp2box = find_xml_node(xml_tree, 'JP2Box', immediate_child=True)
-    jp2codestream = find_xml_node(xml_tree, 'JP2KCodeStream', immediate_child=True)
+    hex_binary_content = get_node_content(
+        find_xml_node(xml_tree, "BinaryContent", immediate_child=True)
+    )
+    decoded_content = find_xml_node(xml_tree, "DecodedContent", immediate_child=True)
+    decoded_geotiff = find_xml_node(xml_tree, "DecodedGeoTIFF", immediate_child=True)
+    text_content = get_node_content(
+        find_xml_node(xml_tree, "TextContent", immediate_child=True)
+    )
+    xml_content = find_xml_node(xml_tree, "XMLContent", immediate_child=True)
+    jp2box = find_xml_node(xml_tree, "JP2Box", immediate_child=True)
+    jp2codestream = find_xml_node(xml_tree, "JP2KCodeStream", immediate_child=True)
 
     if hex_binary_content:
         if decoded_content or decoded_geotiff or text_content or xml_content or jp2box:
-            print('BinaryContent found, and one of DecodedContent/DecodedGeoTIFF/TextContent/XMLContent/JP2Box. The latter will be ignored')
-        if jp2box_name == 'uuid':
-            uuid = get_node_content(find_xml_node(xml_tree, 'UUID', immediate_child=True))
+            print(
+                "BinaryContent found, and one of DecodedContent/DecodedGeoTIFF/TextContent/XMLContent/JP2Box. The latter will be ignored"
+            )
+        if jp2box_name == "uuid":
+            uuid = get_node_content(
+                find_xml_node(xml_tree, "UUID", immediate_child=True)
+            )
             if uuid is None:
-                print('Cannot find JP2Box.UUID element')
+                print("Cannot find JP2Box.UUID element")
                 return False
         else:
-            uuid = ''
-        out_f.write(struct.pack('>I' * 1, 8 + int(len(hex_binary_content) / 2) + int(len(uuid) / 2)))
-        out_f.write(jp2box_name.encode('ascii'))
+            uuid = ""
+        out_f.write(
+            struct.pack(
+                ">I" * 1, 8 + int(len(hex_binary_content) / 2) + int(len(uuid) / 2)
+            )
+        )
+        out_f.write(jp2box_name.encode("ascii"))
         write_hexstring_as_binary(uuid, out_f)
         write_hexstring_as_binary(hex_binary_content, out_f)
 
     elif decoded_content:
         if decoded_geotiff or text_content or xml_content or jp2box:
-            print('DecodedContent found, and one of DecodedGeoTIFF/TextContent/XMLContent/JP2Box. The latter will be ignored')
+            print(
+                "DecodedContent found, and one of DecodedGeoTIFF/TextContent/XMLContent/JP2Box. The latter will be ignored"
+            )
         pos = out_f.tell()
-        out_f.write(struct.pack('>I' * 1, 0))
-        out_f.write(jp2box_name.encode('ascii'))
+        out_f.write(struct.pack(">I" * 1, 0))
+        out_f.write(jp2box_name.encode("ascii"))
         for child_idx in range(XML_FIRST_CHILD_IDX, len(decoded_content)):
             child = decoded_content[child_idx]
-            if child[XML_TYPE_IDX] == gdal.CXT_Element and child[XML_VALUE_IDX] == 'Field':
+            if (
+                child[XML_TYPE_IDX] == gdal.CXT_Element
+                and child[XML_VALUE_IDX] == "Field"
+            ):
                 if not parse_field(child, out_f, src_jp2file):
                     return False
         new_pos = out_f.tell()
         out_f.seek(pos, 0)
-        out_f.write(struct.pack('>I' * 1, new_pos - pos))
+        out_f.write(struct.pack(">I" * 1, new_pos - pos))
         out_f.seek(new_pos, 0)
 
     elif text_content:
         if decoded_geotiff or xml_content or jp2box:
-            print('TextContent found, and one of DecodedGeoTIFF/XMLContent/JP2Box. The latter will be ignored')
-        out_f.write(struct.pack('>I' * 1, 8 + len(text_content)))
-        out_f.write(jp2box_name.encode('ascii'))
-        out_f.write(text_content.encode('latin1'))
+            print(
+                "TextContent found, and one of DecodedGeoTIFF/XMLContent/JP2Box. The latter will be ignored"
+            )
+        out_f.write(struct.pack(">I" * 1, 8 + len(text_content)))
+        out_f.write(jp2box_name.encode("ascii"))
+        out_f.write(text_content.encode("latin1"))
 
     elif xml_content:
         if decoded_geotiff or jp2box:
-            print('XMLContent found, and one of DecodedGeoTIFF/JP2Box. The latter will be ignored')
+            print(
+                "XMLContent found, and one of DecodedGeoTIFF/JP2Box. The latter will be ignored"
+            )
         serialized_xml_content = gdal.SerializeXMLTree(xml_content[XML_FIRST_CHILD_IDX])
-        out_f.write(struct.pack('>I' * 1, 8 + len(serialized_xml_content)))
-        out_f.write(jp2box_name.encode('ascii'))
-        out_f.write(serialized_xml_content.encode('latin1'))
+        out_f.write(struct.pack(">I" * 1, 8 + len(serialized_xml_content)))
+        out_f.write(jp2box_name.encode("ascii"))
+        out_f.write(serialized_xml_content.encode("latin1"))
 
     elif jp2box:
         if decoded_geotiff:
-            print('JP2Box found, and one of DecodedGeoTIFF. The latter will be ignored')
+            print("JP2Box found, and one of DecodedGeoTIFF. The latter will be ignored")
         pos = out_f.tell()
-        out_f.write(struct.pack('>I' * 1, 0))
-        out_f.write(jp2box_name.encode('ascii'))
+        out_f.write(struct.pack(">I" * 1, 0))
+        out_f.write(jp2box_name.encode("ascii"))
         for child_idx in range(XML_FIRST_CHILD_IDX, len(xml_tree)):
             child = xml_tree[child_idx]
-            if child[XML_TYPE_IDX] == gdal.CXT_Element and child[XML_VALUE_IDX] == 'JP2Box':
+            if (
+                child[XML_TYPE_IDX] == gdal.CXT_Element
+                and child[XML_VALUE_IDX] == "JP2Box"
+            ):
                 if not parse_jp2_box(child, out_f, src_jp2file):
                     return False
         new_pos = out_f.tell()
         out_f.seek(pos, 0)
-        out_f.write(struct.pack('>I' * 1, new_pos - pos))
+        out_f.write(struct.pack(">I" * 1, new_pos - pos))
         out_f.seek(new_pos, 0)
 
     elif decoded_geotiff:
-        serialized_xml_content = gdal.SerializeXMLTree(decoded_geotiff[XML_FIRST_CHILD_IDX])
+        serialized_xml_content = gdal.SerializeXMLTree(
+            decoded_geotiff[XML_FIRST_CHILD_IDX]
+        )
 
         vrt_ds = gdal.Open(serialized_xml_content)
         if vrt_ds is None:
-            print('Cannot decode VRTDataset. Outputting empty content')
-            binary_content = ''
+            print("Cannot decode VRTDataset. Outputting empty content")
+            binary_content = ""
         else:
-            tmpfilename = '/vsimem/build_jp2_from_xml_tmp.tif'
-            gdal.GetDriverByName('GTiff').CreateCopy(tmpfilename, vrt_ds)
-            tif_f = gdal.VSIFOpenL(tmpfilename, 'rb')
+            tmpfilename = "/vsimem/build_jp2_from_xml_tmp.tif"
+            gdal.GetDriverByName("GTiff").CreateCopy(tmpfilename, vrt_ds)
+            tif_f = gdal.VSIFOpenL(tmpfilename, "rb")
             binary_content = gdal.VSIFReadL(1, 10000, tif_f)
             gdal.VSIFCloseL(tif_f)
             gdal.Unlink(tmpfilename)
 
-        uuid = get_node_content(find_xml_node(xml_tree, 'UUID', immediate_child=True))
+        uuid = get_node_content(find_xml_node(xml_tree, "UUID", immediate_child=True))
         if uuid is None:
-            uuid = 'B14BF8BD083D4B43A5AE8CD7D5A6CE03'
+            uuid = "B14BF8BD083D4B43A5AE8CD7D5A6CE03"
 
-        out_f.write(struct.pack('>I' * 1, 8 + len(binary_content) + int(len(uuid) / 2)))
-        out_f.write(jp2box_name.encode('ascii'))
+        out_f.write(struct.pack(">I" * 1, 8 + len(binary_content) + int(len(uuid) / 2)))
+        out_f.write(jp2box_name.encode("ascii"))
         write_hexstring_as_binary(uuid, out_f)
         out_f.write(binary_content)
 
     elif jp2codestream:
         pos = out_f.tell()
-        out_f.write(struct.pack('>I' * 1, 0))
-        out_f.write(jp2box_name.encode('ascii'))
+        out_f.write(struct.pack(">I" * 1, 0))
+        out_f.write(jp2box_name.encode("ascii"))
         if not parse_jp2codestream(None, jp2codestream, out_f, src_jp2file):
             return False
         new_pos = out_f.tell()
         out_f.seek(pos, 0)
-        out_f.write(struct.pack('>I' * 1, new_pos - pos))
+        out_f.write(struct.pack(">I" * 1, new_pos - pos))
         out_f.seek(new_pos, 0)
 
     else:
-        data_offset = get_attribute_val(xml_tree, 'data_offset')
+        data_offset = get_attribute_val(xml_tree, "data_offset")
         if data_offset is None:
-            print('Cannot find JP2Box.data_offset attribute')
+            print("Cannot find JP2Box.data_offset attribute")
             return False
         data_offset = int(data_offset)
 
-        data_length = get_attribute_val(xml_tree, 'data_length')
+        data_length = get_attribute_val(xml_tree, "data_length")
         if data_length is None:
-            print('Cannot find JP2Box.data_length attribute')
+            print("Cannot find JP2Box.data_length attribute")
             return False
         data_length = int(data_length)
 
         src_jp2file.seek(data_offset, 0)
         data = src_jp2file.read(data_length)
 
-        out_f.write(struct.pack('>I' * 1, 8 + data_length))
-        out_f.write(jp2box_name.encode('ascii'))
+        out_f.write(struct.pack(">I" * 1, 8 + data_length))
+        out_f.write(jp2box_name.encode("ascii"))
         out_f.write(data)
 
     return True
 
 
 def parse_jp2file(inpath, xml_tree, out_f):
-    src_jp2filename = get_attribute_val(xml_tree, 'filename')
+    src_jp2filename = get_attribute_val(xml_tree, "filename")
     if src_jp2filename is None:
-        print('Cannot find JP2File.filename attribute')
+        print("Cannot find JP2File.filename attribute")
         return False
     if os.path.exists(src_jp2filename):
-        src_jp2file = open(src_jp2filename, 'rb')
+        src_jp2file = open(src_jp2filename, "rb")
     else:
-        src_jp2file = open(os.path.join(inpath, src_jp2filename), 'rb')
+        src_jp2file = open(os.path.join(inpath, src_jp2filename), "rb")
     for child_idx in range(XML_FIRST_CHILD_IDX, len(xml_tree)):
         child = xml_tree[child_idx]
         if child[XML_TYPE_IDX] != gdal.CXT_Element:
@@ -394,6 +432,7 @@ def parse_jp2file(inpath, xml_tree, out_f):
             return False
     return True
 
+
 # Wrapper class for GDAL VSI*L API with class Python file interface
 
 
@@ -420,17 +459,23 @@ def build_file(inname, outname):
     inpath = os.path.dirname(inname)
     xml_tree = gdal.ParseXMLString(open(inname).read())
     if xml_tree is None:
-        print('Cannot parse %s' % inname)
+        print("Cannot parse %s" % inname)
         return False
 
     # out_f = open(outname, 'wb+')
-    out_f = VSILFile(outname, 'wb+')
-    if xml_tree[XML_TYPE_IDX] == gdal.CXT_Element and xml_tree[XML_VALUE_IDX] == 'JP2File':
+    out_f = VSILFile(outname, "wb+")
+    if (
+        xml_tree[XML_TYPE_IDX] == gdal.CXT_Element
+        and xml_tree[XML_VALUE_IDX] == "JP2File"
+    ):
         ret = parse_jp2file(inpath, xml_tree, out_f)
-    elif xml_tree[XML_TYPE_IDX] == gdal.CXT_Element and xml_tree[XML_VALUE_IDX] == 'JP2KCodeStream':
+    elif (
+        xml_tree[XML_TYPE_IDX] == gdal.CXT_Element
+        and xml_tree[XML_VALUE_IDX] == "JP2KCodeStream"
+    ):
         ret = parse_jp2codestream(inpath, xml_tree, out_f)
     else:
-        print('Unexpected node: %s' % xml_tree[XML_VALUE_IDX])
+        print("Unexpected node: %s" % xml_tree[XML_VALUE_IDX])
         ret = False
     out_f.close()
 
@@ -442,7 +487,7 @@ def main(argv=sys.argv):
     inname = None
     outname = None
     while i < len(argv):
-        if sys.argv[i][0] == '-':
+        if sys.argv[i][0] == "-":
             return Usage()
         elif inname is None:
             inname = sys.argv[i]
@@ -461,5 +506,5 @@ def main(argv=sys.argv):
     return 1
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(main(sys.argv))
