@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.10
 # ******************************************************************************
 #
 #  Project:  GDAL
@@ -28,15 +28,21 @@
 # ******************************************************************************
 
 import sys
+
 import numpy as np
 
 from osgeo import gdal, gdal_array
 
 
+def Usage():
+    print("Usage: classify.py src_filename dst_filename")
+    print("")
+    print("  classify.py utm.tif classes.tif")
+    return 2
+
+
 def doit(src_filename, dst_filename):
-    class_defs = [(1, 10, 20),
-                  (2, 20, 30),
-                  (3, 128, 255)]
+    class_defs = [(1, 10, 20), (2, 20, 30), (3, 128, 255)]
 
     src_ds = gdal.Open(src_filename)
     xsize = src_ds.RasterXSize
@@ -55,22 +61,23 @@ def doit(src_filename, dst_filename):
 
         mask = np.bitwise_and(
             np.greater_equal(src_image, class_start),
-            np.less_equal(src_image, class_end))
+            np.less_equal(src_image, class_end),
+        )
 
         dst_image = np.choose(mask, (dst_image, class_value))
 
     gdal_array.SaveArray(dst_image, dst_filename)
 
 
-def main(argv=sys.argv):
-    src_filename = 'utm.tif'
-    dst_filename = 'classes.tif'
+def main(argv=sys.argv, src_filename=None, dst_filename=None):
     if len(argv) > 1:
         src_filename = argv[1]
     if len(argv) > 2:
         dst_filename = argv[2]
+    if not src_filename or not dst_filename:
+        return Usage()
     return doit(src_filename, dst_filename)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(main(sys.argv))
