@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.10
 # -*- coding: utf-8 -*-
 # ******************************************************************************
 #  $Id$
@@ -37,29 +37,29 @@ import webbrowser
 from osgeo import gdal
 
 SCOPES = {
-    'ft': 'https://www.googleapis.com/auth/fusiontables',
-    'storage': 'https://www.googleapis.com/auth/devstorage.read_only',
-    'storage-rw': 'https://www.googleapis.com/auth/devstorage.read_write'
+    "ft": "https://www.googleapis.com/auth/fusiontables",
+    "storage": "https://www.googleapis.com/auth/devstorage.read_only",
+    "storage-rw": "https://www.googleapis.com/auth/devstorage.read_write",
 }
 
 
 def Usage():
-    print('')
-    print('Usage: gdal_auth_py [-s scope]')
-    print('       - interactive use.')
-    print('')
-    print('or:')
-    print('Usage: gdal_auth.py login [-s scope] ')
-    print('Usage: gdal_auth.py auth2refresh [-s scope] auth_token')
-    print('Usage: gdal_auth.py refresh2access [-s scope] refresh_token')
-    print('')
-    print('scopes: ft/storage/storage-rw/full_url')
-    print('')
-    return 1
+    print("")
+    print("Usage: gdal_auth_py [-s scope]")
+    print("       - interactive use.")
+    print("")
+    print("or:")
+    print("Usage: gdal_auth.py login [-s scope] ")
+    print("Usage: gdal_auth.py auth2refresh [-s scope] auth_token")
+    print("Usage: gdal_auth.py refresh2access [-s scope] refresh_token")
+    print("")
+    print("scopes: ft/storage/storage-rw/full_url")
+    print("")
+    return 2
 
 
 def main(argv=sys.argv):
-    scope = SCOPES['ft']
+    scope = SCOPES["ft"]
     token_in = None
     command = None
 
@@ -72,17 +72,17 @@ def main(argv=sys.argv):
     while i < len(argv):
         arg = argv[i]
 
-        if arg == '-s' and i < len(argv) - 1:
+        if arg == "-s" and i < len(argv) - 1:
             if argv[i + 1] in SCOPES:
                 scope = SCOPES[argv[i + 1]]
-            elif argv[i + 1].startswith('http'):
+            elif argv[i + 1].startswith("http"):
                 scope = argv[i + 1]
             else:
-                print('Scope %s not recognised.' % argv[i + 1])
+                print("Scope %s not recognised." % argv[i + 1])
                 return Usage()
             i = i + 1
 
-        elif arg[0] == '-':
+        elif arg[0] == "-":
             return Usage()
 
         elif command is None:
@@ -97,42 +97,42 @@ def main(argv=sys.argv):
         i = i + 1
 
     if command is None:
-        command = 'interactive'
+        command = "interactive"
 
-    if command == 'login':
+    if command == "login":
         print(gdal.GOA2GetAuthorizationURL(scope))
-    elif command == 'auth2refresh':
+    elif command == "auth2refresh":
         print(gdal.GOA2GetRefreshToken(token_in, scope))
-    elif command == 'refresh2access':
+    elif command == "refresh2access":
         print(gdal.GOA2GetAccessToken(token_in, scope))
-    elif command != 'interactive':
+    elif command != "interactive":
         return Usage()
     else:
         # Interactive case
-        print('Authorization requested for scope:')
+        print("Authorization requested for scope:")
         print(scope)
-        print('')
-        print('Please login and authorize access in web browser...')
+        print("")
+        print("Please login and authorize access in web browser...")
 
         webbrowser.open(gdal.GOA2GetAuthorizationURL(scope))
 
         time.sleep(2.0)
 
-        print('')
-        print('Enter authorization token:')
+        print("")
+        print("Enter authorization token:")
         auth_token = sys.stdin.readline()
 
         refresh_token = gdal.GOA2GetRefreshToken(auth_token, scope)
 
-        print('Refresh Token:' + refresh_token)
-        print('')
-        if scope == SCOPES['ft']:
-            print('Consider setting a configuration option like:')
-            print('GFT_REFRESH_TOKEN=' + refresh_token)
-        elif scope in (SCOPES['storage'], SCOPES['storage-rw']):
-            print('Consider setting a configuration option like:')
-            print('GS_OAUTH2_REFRESH_TOKEN=' + refresh_token)
+        print("Refresh Token:" + refresh_token)
+        print("")
+        if scope == SCOPES["ft"]:
+            print("Consider setting a configuration option like:")
+            print("GFT_REFRESH_TOKEN=" + refresh_token)
+        elif scope in (SCOPES["storage"], SCOPES["storage-rw"]):
+            print("Consider setting a configuration option like:")
+            print("GS_OAUTH2_REFRESH_TOKEN=" + refresh_token)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(main(sys.argv))
