@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.10
 ###############################################################################
 # $Id$
 #
@@ -34,8 +34,8 @@ from osgeo import gdal
 
 
 def Usage():
-    print('Usage: gdal_rmdir filename')
-    return -1
+    print("Usage: gdal_rmdir filename")
+    return 2
 
 
 def gdal_rm(argv, progress=None):
@@ -48,15 +48,15 @@ def gdal_rm(argv, progress=None):
         return -1
 
     for i in range(1, len(argv)):
-        if argv[i] == '-r':
+        if argv[i] == "-r":
             recursive = True
         elif filename is None:
             filename = argv[i]
-        elif argv[i][0] == '-':
-            print('Unexpected option : %s' % argv[i])
+        elif argv[i][0] == "-":
+            print("Unexpected option : %s" % argv[i])
             return Usage()
         else:
-            print('Unexpected option : %s' % argv[i])
+            print("Unexpected option : %s" % argv[i])
             return Usage()
 
     if filename is None:
@@ -67,7 +67,7 @@ def gdal_rm(argv, progress=None):
     else:
         ret = gdal.Rmdir(filename)
     if ret != 0:
-        print('Deletion failed')
+        print("Deletion failed")
     return ret
 
 
@@ -75,5 +75,5 @@ def main(argv=sys.argv):
     return gdal_rm(argv)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(main(sys.argv))
