@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.10
 ###############################################################################
 # $Id$
 #
@@ -37,12 +37,12 @@ from osgeo import gdal
 
 
 def Usage():
-    print('Usage: histrep.py [-force] input_file')
-    print('   or')
-    print('       histrep.py -req <min> <max> <buckets> [-force] [-approxok]')
-    print('                  [-ioor] input_file')
-    print('')
-    return 1
+    print("Usage: histrep.py [-force] input_file")
+    print("   or")
+    print("       histrep.py -req <min> <max> <buckets> [-force] [-approxok]")
+    print("                  [-ioor] input_file")
+    print("")
+    return 2
 
 
 def main(argv=sys.argv):
@@ -60,29 +60,29 @@ def main(argv=sys.argv):
     while i < len(argv):
         arg = argv[i]
 
-        if arg == '-req':
+        if arg == "-req":
             req = (float(argv[i + 1]), float(argv[i + 2]), int(argv[i + 3]))
             i = i + 3
 
-        elif arg == '-ioor':
+        elif arg == "-ioor":
             ioor = 1
 
-        elif arg == '-approxok':
+        elif arg == "-approxok":
             approxok = 1
 
-        elif arg == '-force':
+        elif arg == "-force":
             force = 1
 
         elif filename is None:
             filename = arg
 
         else:
-            Usage()
+            return Usage()
 
         i = i + 1
 
     if filename is None:
-        Usage()
+        return Usage()
 
     # -----------------------------------------------------------------------
     ds = gdal.Open(filename)
@@ -91,24 +91,23 @@ def main(argv=sys.argv):
         hist = ds.GetRasterBand(1).GetDefaultHistogram(force=force)
 
         if hist is None:
-            print('No default histogram.')
+            print("No default histogram.")
         else:
-            print('Default Histogram:')
-            print('Min: ', hist[0])
-            print('Max: ', hist[1])
-            print('Buckets: ', hist[2])
-            print('Histogram: ', hist[3])
+            print("Default Histogram:")
+            print("Min: ", hist[0])
+            print("Max: ", hist[1])
+            print("Buckets: ", hist[2])
+            print("Histogram: ", hist[3])
 
     else:
-        hist = ds.GetRasterBand(1).GetHistogram(req[0], req[1], req[2],
-                                                ioor, approxok)
+        hist = ds.GetRasterBand(1).GetHistogram(req[0], req[1], req[2], ioor, approxok)
 
         if hist is not None:
-            print('Histogram: ', hist)
+            print("Histogram: ", hist)
 
     ds = None
     return 0
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(main(sys.argv))
